@@ -1,4 +1,4 @@
-=head1 => NAME
+=head1 NAME
 
 AnyEvent - provide framework for multiple event loops
 
@@ -20,6 +20,12 @@ EV, Event, Glib, Tk, Perl, Event::Lib, Qt, POE - various supported event loops
    $w->send; # wake up current and all future recv's
    $w->recv; # enters "main loop" till $condvar gets ->send
 
+=head1 INTRODUCTION/TUTORIAL
+
+This manpage is mainly a reference manual. If you are interested
+in a tutorial or some gentle introduction, have a look at the
+L<AnyEvent::Intro> manpage.
+
 =head1 WHY YOU SHOULD USE THIS MODULE (OR NOT)
 
 Glib, POE, IO::Async, Event... CPAN offers event models by the dozen
@@ -134,10 +140,10 @@ example), or need to refer to their watcher object in other ways.
 
 An any way to achieve that is this pattern:
 
-  my $w; $w = AnyEvent->type (arg => value ..., cb => sub {
-     # you can use $w here, for example to undef it
-     undef $w;
-  });
+   my $w; $w = AnyEvent->type (arg => value ..., cb => sub {
+      # you can use $w here, for example to undef it
+      undef $w;
+   });
 
 Note that C<my $w; $w => combination. This is necessary because in Perl,
 my variables are only visible after the statement in which they are
@@ -348,21 +354,21 @@ C<fork> the child (alternatively, you can call C<AnyEvent::detect>).
 
 Example: fork a process and wait for it
 
-  my $done = AnyEvent->condvar;
-
-  my $pid = fork or exit 5;
-
-  my $w = AnyEvent->child (
-     pid => $pid,
-     cb  => sub {
-        my ($pid, $status) = @_;
-        warn "pid $pid exited with status $status";
-        $done->send;
-     },
-  );
-
-  # do something else, then wait for process exit
-  $done->recv;
+   my $done = AnyEvent->condvar;
+  
+   my $pid = fork or exit 5;
+  
+   my $w = AnyEvent->child (
+      pid => $pid,
+      cb  => sub {
+         my ($pid, $status) = @_;
+         warn "pid $pid exited with status $status";
+         $done->send;
+      },
+   );
+  
+   # do something else, then wait for process exit
+   $done->recv;
 
 =head2 CONDITION VARIABLES
 
@@ -593,8 +599,9 @@ This is a mutator function that returns the callback set and optionally
 replaces it before doing so.
 
 The callback will be called when the condition becomes "true", i.e. when
-C<send> or C<croak> are called. Calling C<recv> inside the callback
-or at any later time is guaranteed not to block.
+C<send> or C<croak> are called, with the only argument being the condition
+variable itself. Calling C<recv> inside the callback or at any later time
+is guaranteed not to block.
 
 =back
 
@@ -802,7 +809,7 @@ use strict;
 
 use Carp;
 
-our $VERSION = 4.11;
+our $VERSION = 4.12;
 our $MODEL;
 
 our $AUTOLOAD;
@@ -1168,7 +1175,7 @@ This functionality might change in future versions.
 For example, to force the pure perl model (L<AnyEvent::Impl::Perl>) you
 could start your program like this:
 
-  PERL_ANYEVENT_MODEL=Perl perl ...
+   PERL_ANYEVENT_MODEL=Perl perl ...
 
 =item C<PERL_ANYEVENT_PROTOCOLS>
 
@@ -1653,9 +1660,9 @@ specified in the variable.
 You can make AnyEvent completely ignore this variable by deleting it
 before the first watcher gets created, e.g. with a C<BEGIN> block:
 
-  BEGIN { delete $ENV{PERL_ANYEVENT_MODEL} }
-
-  use AnyEvent;
+   BEGIN { delete $ENV{PERL_ANYEVENT_MODEL} }
+  
+   use AnyEvent;
 
 Similar considerations apply to $ENV{PERL_ANYEVENT_VERBOSE}, as that can
 be used to probe what backend is used and gain other information (which is
@@ -1686,8 +1693,8 @@ Nontrivial usage examples: L<Net::FCP>, L<Net::XMPP2>, L<AnyEvent::DNS>.
 
 =head1 AUTHOR
 
- Marc Lehmann <schmorp@schmorp.de>
- http://home.schmorp.de/
+   Marc Lehmann <schmorp@schmorp.de>
+   http://home.schmorp.de/
 
 =cut
 
